CallProgressCallback class abstract

Protocol to receive updates on call status changes during call lifecycle

Constructors

CallProgressCallback()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onCallDeclined(String callType, String callFrom) → void
Called when a call is declined
onCallEnded(String callType, String did) → void
Called when a call ends
onCallError(String error, String? callType) → void
Called when an error occurs during call operations
onCallStarted(String callType, String did, String registeredNumber) → void
Called when a call starts
onCallStatusChanged(CallStatus status) → void
Called when call status changes
onWebSocketStatusChanged(bool isConnected) → void
Called when WebSocket connection status changes
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited