CallStatus class

Represents the current state of a call including if it is ongoing, muted, or on hold

Constructors

CallStatus({required bool isCallOngoing, required bool isMuted, required bool isOnHold, bool isSpeakerOn = false, String? callType, String? currentDID, String? registeredNumber})
const

Properties

callType String?
The current call type
final
currentDID String?
The current DID (Direct Inward Dialing) number
final
hashCode int
The hash code for this object.
no setteroverride
isCallOngoing bool
Whether a call is currently ongoing
final
isMuted bool
Whether the call is currently muted
final
isOnHold bool
Whether the call is currently on hold
final
isSpeakerOn bool
Whether the speaker is enabled
final
registeredNumber String?
The registered phone number
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({bool? isCallOngoing, bool? isMuted, bool? isOnHold, bool? isSpeakerOn, String? callType, String? currentDID, String? registeredNumber}) CallStatus
Creates a copy of this CallStatus with the given fields replaced by new values
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override