CallType enum
Enumerates the direction of a call: inbound, outbound, or app-to-app
- Inheritance
- Available extensions
Values
- inbound → const CallType
-
Inbound call - calling from App to Server through websocket
- outbound → const CallType
-
Outbound call - call comes from server to app through VoIP push notifications
- appToApp → const CallType
-
App-to-App call - call from one app to another app through VoIP notifications
- appToAppOutbound → const CallType
-
App-to-App outbound call variant
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
Available on CallType, provided by the CallTypeExtension extension
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited