IncomingCallData class
Data model for incoming call information This class bridges our existing call data with flutter_callkit_incoming requirements
Constructors
-
IncomingCallData({required String id, required String callFrom, required String callTo, required String callType, required String callerName, required String registeredNumber, String? callId, String? environment, int? timestamp, String? reason, String? action, Map<
String, dynamic> ? extra}) -
const
-
IncomingCallData.fromPushPayload(Map<
String, dynamic> payload) -
Create IncomingCallData from push notification payload
factory
Properties
- action → String?
-
final
- callerName → String
-
final
- callFrom → String
-
final
- callId → String?
-
final
- callTo → String
-
final
- callType → String
-
final
- environment → String?
-
final
-
extra
→ Map<
String, dynamic> ? -
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → String
-
final
- isCallEnd → bool
-
Check if this is a call end event
no setter
- isInitialCall → bool
-
Check if this is an initial call event
no setter
- reason → String?
-
final
- registeredNumber → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp → int?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toCallKitMap(
{String appName = 'OneCxi', String? avatar, int duration = 30000, String textAccept = 'Accept', String textDecline = 'Decline', String textMissedCall = 'Missed Call', String textCallback = 'Call Back'}) → Map< String, dynamic> - Convert to Map for flutter_callkit_incoming This creates a Map that can be converted to CallKitParams by the plugin
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override