OneCxiError enum
Custom error types for the OneCxi Flutter SDK
Values
- notInitialized → const OneCxiError
- invalidInput → const OneCxiError
- audioSessionSetupFailed → const OneCxiError
- webSocketConnectionFailed → const OneCxiError
- permissionDenied → const OneCxiError
- callInProgress → const OneCxiError
- noCallInProgress → const OneCxiError
- initializationFailed → const OneCxiError
- callFailed → const OneCxiError
- callEndFailed → const OneCxiError
- incomingCallFailed → const OneCxiError
- speakerControlFailed → const OneCxiError
- holdControlFailed → const OneCxiError
- muteControlFailed → const OneCxiError
- unknown → const OneCxiError
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- message → String
-
Get the error message for this error type
no setter
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromPlatformException(
PlatformException exception) → OneCxiError - Create OneCxiError from PlatformException
Constants
-
values
→ const List<
OneCxiError> - A constant List of the values in this enum, in order of their declaration.