OneCxiSdk class
Methods
canUseFullScreenIntent ()
→ Future <bool >
Whether the app may show full-screen incoming-call UI.
checkCallAcceptAction ()
→ Future <Map <String , dynamic > ? >
Check for call accept action from Android SharedPreferences
checkCallEndedState ()
→ Future <Map <String , dynamic > ? >
Check for call ended state via SharedPreferences
checkForPermissions ()
→ Future <bool >
Check if all required permissions are granted
checkPendingIncomingCall ()
→ Future <Map <String , dynamic > ? >
Check for pending incoming call from FCM (Android only)
clearCallAcceptAction ()
→ Future <void >
Clear call accept action from Android SharedPreferences
clearPendingIncomingCall ()
→ Future <void >
Clear pending incoming call data (Android only)
dispose ()
→ void
Dispose resources
endCall ()
→ Future <void >
End the current call
endCallFromFlutter ()
→ Future <void >
End call from Flutter (notify native layer to end active call UI/service)
endCurrentCall ()
→ Future <void >
End current call from CallKit
endNativeServiceIfRunning ()
→ Future <void >
Stop native Android call service if still running.
ensureFullScreenIntentPermission ()
→ Future <bool >
Ensures the app can show full-screen incoming-call UI on Android 14+.
forceEndCall ()
→ Future <void >
Force end call from native service
getAccountName ()
→ String ?
getApiKey ()
→ String ?
getCallStatus ()
→ CallStatus
Get current call status
getFcmToken ()
→ Future <String ? >
Get FCM token for Android
getPlatform ()
→ Future <String >
Get the current platform (iOS/Android)
getPlatformToken ()
→ Future <String ? >
Get the appropriate platform token (FCM for Android, VoIP for iOS)
getServerName ()
→ String ?
getVoipToken ()
→ Future <String ? >
Get VoIP token for iOS
handleCallAnswered (Map <String , dynamic > callData )
→ Future <void >
Handle call answered from native CallKit
handleCallEnded (Map <String , dynamic > callData )
→ Future <void >
Handle call ended from native CallKit
handleIncomingCall ({required String from , required String callType , required String registeredNumber })
→ Future <void >
Handle incoming call from VoIP push notification
handleIncomingCallWithUI (Map <String , dynamic > pushPayload )
→ Future <void >
Handle incoming call with flutter_callkit_incoming UI
holdCall (bool hold )
→ Future <void >
Hold or resume the call
initialize ({required String accountName , required String apiKey , required String serverName , bool autoStartOnBoot = false })
→ Future <void >
Initialize the SDK with account credentials.
muteCall (bool mute )
→ Future <void >
Mute or unmute the call
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
refreshCallStatus ()
→ Future <void >
Refresh call status
requestPermissions ()
→ Future <bool >
Request necessary permissions
resumeAcceptedCallIfAny ()
→ Future <bool >
Resume a call that was accepted from a killed/locked state via CallKit.
Call this once on app startup (after initialize ); it connects the call
if the launch was triggered by accepting an incoming call. Returns true
if a call was resumed.
sendDTMF (String digit )
→ void
Send DTMF tone
setCallProgressCallback (CallProgressCallback callback )
→ void
Set the callback for call progress updates
setSpeaker (bool enabled )
→ Future <void >
Set speaker mode
startAppToAppInboundCall ({required String inputNumber , required String registeredNumber })
→ Future <void >
Start an app-to-app inbound call
startAppToAppOutboundCall ({required String inputNumber , required String registeredNumber , required String callFromNumber })
→ Future <void >
Start an app-to-app outbound call
startInBoundCall ({required String did , required String registeredNumber })
→ Future <void >
Start an inbound call (App to Server via WebSocket)
startOutBoundCall ({required String userMobile , required String registeredNumber })
→ Future <void >
Start an outbound call (Server to App via VoIP)
storeRegisteredNumber (String userNumber )
→ Future <void >
Store registered number in Android SharedPreferences (Android only)
toString ()
→ String
A string representation of this object.
inherited